@@ -2,7 +2,7 @@
 # Application: pyFind
 # File:        __init__.py
 # Description: 
-# Copyright (c) 2001   Andy Balcombe <kinematics _at_ ntlworld.com>
+# Copyright (c) 2001-2002   Andy Balcombe <kinematics _at_ ntlworld.com>
 ###
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,5 +19,24 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+"""pyFind package"""
 
-# This file is here only as a package placeholder.
+#i18n stuff 
+try:
+    import gettext
+    import commands
+    
+    domain = 'pyfind'
+    
+    data_dir = commands.getoutput('gnome-config --datadir')
+    locale_dir = data_dir + '/locale'
+    
+    gettext.bindtextdomain(domain, locale_dir)
+    gettext.textdomain(domain)
+    
+except IOError:
+    print "IOError in __init__.py"
+    pass
+    
+import __builtin__
+__builtin__.__dict__['_'] = gettext.gettext
